# ziamath

Render MathML or LaTeX Math expressions as SVG using pure Python. Does not require a Latex installation, nor a network connection.

Ziamath comes with the STIXTwoMath-Regular font installed for use by default.
Other Math-enabled Open Type fonts (TTF or OTF files) may also be used.

![Example](https://github.com/cdelker/ziamath/blob/05e25b1789acc8ee816971d384aa851ffb197f7a/example.png)

Documentation is available at [readthedocs](https://ziamath.readthedocs.io).

Also try the [online demo](https://cdelker.github.io/pyscript/ziamath.html) based on Pyscript.
